@@ -1,6 +1,8 @@
 use core_foundation_sys::array::CFArrayRef;
 use core_foundation_sys::base::CFAllocatorRef;
-use core_foundation_sys::base::{Boolean, CFTypeRef, OSStatus};
+#[cfg(target_os = "macos")]
+use core_foundation_sys::base::CFTypeRef;
+use core_foundation_sys::base::{Boolean, OSStatus};
 use std::os::raw::{c_char, c_int, c_void};
 
 use crate::cipher_suite::SSLCipherSuite;
@@ -28,15 +30,13 @@ pub type SSLSessionOption = c_int;
 pub const kSSLSessionOptionBreakOnServerAuth: SSLSessionOption = 0;
 pub const kSSLSessionOptionBreakOnCertRequested: SSLSessionOption = 1;
 pub const kSSLSessionOptionBreakOnClientAuth: SSLSessionOption = 2;
-#[cfg(any(feature = "OSX_10_9", target_os = "ios"))]
 pub const kSSLSessionOptionFalseStart: SSLSessionOption = 3;
-#[cfg(any(feature = "OSX_10_9", target_os = "ios"))]
 pub const kSSLSessionOptionSendOneByteRecord: SSLSessionOption = 4;
-#[cfg(all(feature = "OSX_10_11", not(target_os = "ios")))]
+#[cfg(all(feature = "OSX_10_11", not(any(target_os = "ios", target_os = "tvos", target_os = "watchos", target_os = "visionos"))))]
 pub const kSSLSessionOptionAllowServerIdentityChange: SSLSessionOption = 5;
-#[cfg(all(feature = "OSX_10_10", not(target_os = "ios")))]
+#[cfg(all(feature = "OSX_10_10", not(any(target_os = "ios", target_os = "tvos", target_os = "watchos", target_os = "visionos"))))]
 pub const kSSLSessionOptionFallback: SSLSessionOption = 6;
-#[cfg(all(feature = "OSX_10_11", not(target_os = "ios")))]
+#[cfg(all(feature = "OSX_10_11", not(any(target_os = "ios", target_os = "tvos", target_os = "watchos", target_os = "visionos"))))]
 pub const kSSLSessionOptionBreakOnClientHello: SSLSessionOption = 7;
 
 pub type SSLSessionState = c_int;
@@ -46,9 +46,11 @@ pub const kSSLConnected: SSLSessionState = 2;
 pub const kSSLClosed: SSLSessionState = 3;
 pub const kSSLAborted: SSLSessionState = 4;
 
-pub type SSLReadFunc =
-    unsafe extern "C" fn(connection: SSLConnectionRef, data: *mut c_void, dataLength: *mut usize)
-        -> OSStatus;
+pub type SSLReadFunc = unsafe extern "C" fn(
+    connection: SSLConnectionRef,
+    data: *mut c_void,
+    dataLength: *mut usize,
+) -> OSStatus;
 
 pub type SSLWriteFunc = unsafe extern "C" fn(
     connection: SSLConnectionRef,
@@ -266,4 +268,6 @@ extern "C" {
     pub fn SSLSetALPNProtocols(context: SSLContextRef, protocols: CFArrayRef) -> OSStatus;
     #[cfg(feature = "OSX_10_13")]
     pub fn SSLCopyALPNProtocols(context: SSLContextRef, protocols: *mut CFArrayRef) -> OSStatus;
+    #[cfg(feature = "OSX_10_13")]
+    pub fn SSLSetSessionTicketsEnabled(context: SSLContextRef, enabled: Boolean) -> OSStatus;
 }
